@@ -16,7 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+ * USA.
  *
  * Note: This code is heavily based on the GNU MP Library.
  *	 Actually it's the same code with only minor changes in the
@@ -49,16 +50,16 @@
   typedef unsigned short int mpi_limb_t;
   typedef   signed short int mpi_limb_signed_t;
 #else
-  #error BYTES_PER_MPI_LIMB does not match any C type
+#error BYTES_PER_MPI_LIMB does not match any C type
 #endif
 #define BITS_PER_MPI_LIMB    (8*BYTES_PER_MPI_LIMB)
 
 #ifndef EXTERN_UNLESS_MAIN_MODULE
- #if defined (__riscos__) && !defined (INCLUDED_BY_MAIN_MODULE)
-  #define EXTERN_UNLESS_MAIN_MODULE extern
- #else
-  #define EXTERN_UNLESS_MAIN_MODULE 
- #endif
+#if defined (__riscos__) && !defined (INCLUDED_BY_MAIN_MODULE)
+#define EXTERN_UNLESS_MAIN_MODULE extern
+#else
+#define EXTERN_UNLESS_MAIN_MODULE 
+#endif
 #endif
 
 #define DBG_MPI     mpi_debug_mode
@@ -68,7 +69,7 @@ EXTERN_UNLESS_MAIN_MODULE int mpi_debug_mode;
 struct gcry_mpi {
     int alloced;    /* array size (# of allocated limbs) */
     int nlimbs;     /* number of valid limbs */
-    int nbits;	    /* the real number of valid bits (info only) */
+    unsigned int nbits; /* the real number of valid bits (info only) */
     int sign;	    /* indicates a negative number */
     unsigned flags; /* bit 0: array must be allocated in secure memory space */
 		    /* bit 1: not used */
@@ -86,29 +87,29 @@ typedef struct gcry_mpi *MPI;
 /*-- mpiutil.c --*/
 
 #ifdef M_DEBUG
-  #define mpi_alloc(n)	      mpi_debug_alloc((n), M_DBGINFO( __LINE__ ) )
-  #define mpi_alloc_secure(n) mpi_debug_alloc_secure((n), M_DBGINFO( __LINE__ ) )
-  #define mpi_alloc_like(n)   mpi_debug_alloc_like((n), M_DBGINFO( __LINE__ ) )
-  #define mpi_free(a)	      mpi_debug_free((a), M_DBGINFO(__LINE__) )
-  #define mpi_resize(a,b)     mpi_debug_resize((a),(b), M_DBGINFO(__LINE__) )
-  #define mpi_copy(a)	      mpi_debug_copy((a), M_DBGINFO(__LINE__) )
-  MPI mpi_debug_alloc( unsigned nlimbs, const char *info );
-  MPI mpi_debug_alloc_secure( unsigned nlimbs, const char *info );
-  MPI mpi_debug_alloc_like( MPI a, const char *info );
-  void mpi_debug_free( MPI a, const char *info );
-  void mpi_debug_resize( MPI a, unsigned nlimbs, const char *info );
-  MPI  mpi_debug_copy( MPI a, const char *info	);
+#define mpi_alloc(n)	      mpi_debug_alloc((n), M_DBGINFO( __LINE__ ) )
+#define mpi_alloc_secure(n) mpi_debug_alloc_secure((n), M_DBGINFO( __LINE__ ) )
+#define mpi_alloc_like(n)   mpi_debug_alloc_like((n), M_DBGINFO( __LINE__ ) )
+#define mpi_free(a)	      mpi_debug_free((a), M_DBGINFO(__LINE__) )
+#define mpi_resize(a,b)     mpi_debug_resize((a),(b), M_DBGINFO(__LINE__) )
+#define mpi_copy(a)	      mpi_debug_copy((a), M_DBGINFO(__LINE__) )
+MPI mpi_debug_alloc( unsigned nlimbs, const char *info );
+MPI mpi_debug_alloc_secure( unsigned nlimbs, const char *info );
+MPI mpi_debug_alloc_like( MPI a, const char *info );
+void mpi_debug_free( MPI a, const char *info );
+void mpi_debug_resize( MPI a, unsigned nlimbs, const char *info );
+MPI  mpi_debug_copy( MPI a, const char *info	);
 #else
-  MPI mpi_alloc( unsigned nlimbs );
-  MPI mpi_alloc_secure( unsigned nlimbs );
-  MPI mpi_alloc_like( MPI a );
-  void mpi_free( MPI a );
-  void mpi_resize( MPI a, unsigned nlimbs );
-  MPI  mpi_copy( MPI a );
+MPI mpi_alloc( unsigned nlimbs );
+MPI mpi_alloc_secure( unsigned nlimbs );
+MPI mpi_alloc_like( MPI a );
+void mpi_free( MPI a );
+void mpi_resize( MPI a, unsigned nlimbs );
+MPI  mpi_copy( MPI a );
 #endif
 #define mpi_is_opaque(a) ((a) && ((a)->flags&4))
-MPI mpi_set_opaque( MPI a, void *p, int len );
-void *mpi_get_opaque( MPI a, int *len );
+MPI mpi_set_opaque( MPI a, void *p, unsigned int len );
+void *mpi_get_opaque( MPI a, unsigned int *len );
 #define mpi_is_secure(a) ((a) && ((a)->flags&1))
 void mpi_set_secure( MPI a );
 void mpi_clear( MPI a );
@@ -121,10 +122,10 @@ void mpi_swap( MPI a, MPI b);
 /*-- mpicoder.c --*/
 int mpi_write( IOBUF out, MPI a );
 #ifdef M_DEBUG
-  #define mpi_read(a,b,c)   mpi_debug_read((a),(b),(c),  M_DBGINFO( __LINE__ ) )
-  MPI mpi_debug_read(IOBUF inp, unsigned *nread, int secure, const char *info);
+#define mpi_read(a,b,c)   mpi_debug_read((a),(b),(c),  M_DBGINFO( __LINE__ ) )
+MPI mpi_debug_read(IOBUF inp, unsigned *nread, int secure, const char *info);
 #else
-  MPI mpi_read(IOBUF inp, unsigned *nread, int secure);
+MPI mpi_read(IOBUF inp, unsigned *nread, int secure);
 #endif
 MPI mpi_read_from_buffer(byte *buffer, unsigned *ret_nread, int secure);
 int mpi_fromstr(MPI val, const char *str);
@@ -166,7 +167,7 @@ int mpi_gcd( MPI g, MPI a, MPI b );
 
 /*-- mpi-pow.c --*/
 void mpi_pow( MPI w, MPI u, MPI v);
-void mpi_powm( MPI res, MPI base, MPI exp, MPI mod);
+void mpi_powm( MPI res, MPI base, MPI exponent, MPI mod);
 
 /*-- mpi-mpow.c --*/
 void mpi_mulpowm( MPI res, MPI *basearray, MPI *exparray, MPI mod);
@@ -193,5 +194,4 @@ void mpi_rshift( MPI x, MPI a, unsigned n );
 /*-- mpi-inv.c --*/
 void mpi_invm( MPI x, MPI u, MPI v );
 
-
 #endif /*G10_MPI_H*/
